summaryrefslogtreecommitdiff
path: root/libavformat/rtpenc_h261.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavformat/rtpenc_h261.c')
-rw-r--r--libavformat/rtpenc_h261.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libavformat/rtpenc_h261.c b/libavformat/rtpenc_h261.c
index 514e7bf9ca..550f04f395 100644
--- a/libavformat/rtpenc_h261.c
+++ b/libavformat/rtpenc_h261.c
@@ -72,12 +72,12 @@ void ff_rtp_send_h261(AVFormatContext *ctx, const uint8_t *frame_buf, int frame_
rtp_ctx->buf[2] = 0; /* quant=0, hmvd=5 */
rtp_ctx->buf[3] = 0; /* vmvd=0 */
if (frame_size < 2 || frame_buf[0] != 0 || frame_buf[1] != 1) {
/* A full, correct fix for this would be to make the H261 encoder
* support inserting extra GOB headers (triggered by setting e.g.
* "-ps 1"), and including information about macroblock boundaries
* (such as for h263_rfc2190). */
av_log(ctx, AV_LOG_WARNING,
- "RTP/H261 packet not cut at a GOB boundary, not signaled correctly\n");
+ "RTP/H.261 packet not cut at a GOB boundary, not signaled correctly\n");
}
cur_frame_size = FFMIN(rtp_ctx->max_payload_size - RTP_H261_HEADER_SIZE, frame_size);
@@ -72,12 +72,12 @@ void ff_rtp_send_h261(AVFormatContext *ctx, const uint8_t *frame_buf, int frame_
rtp_ctx->buf[3] = 0; /* vmvd=0 */
if (frame_size < 2 || frame_buf[0] != 0 || frame_buf[1] != 1) {
- /* A full, correct fix for this would be to make the H261 encoder
+ /* A full, correct fix for this would be to make the H.261 encoder
* support inserting extra GOB headers (triggered by setting e.g.
* "-ps 1"), and including information about macroblock boundaries